phone

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2022 License: GPL-3.0 Imports: 4 Imported by: 7

README

phone

Phone is a wrapper of github.com/nyaruka/phonenumbers to manage the phone numbers.

Documentation

Index

Constants

const (
	// DefaultCountryCodeNumberID is the default country code number used for parsing using ID.
	DefaultCountryCodeNumberID = 62
)

Variables

This section is empty.

Functions

func NormalizeID

func NormalizeID(phoneNumber string, countryCode int) (res string)

NormalizeID parses the phone number using the countryCode. It returns the normalized phone number and the country code. The default country code is ID.

Types

This section is empty.

Jump to