Documentation
¶
Index ¶
Constants ¶
const (
// DefaultCountryCodeNumberID is the default country code number used for parsing using ID.
DefaultCountryCodeNumberID = 62
)
Variables ¶
This section is empty.
Functions ¶
func NormalizeID ¶
NormalizeID parses the phone number using the countryCode. It returns the normalized phone number and the country code. The default country code is ID.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.